@@ -1,4 +1,4 @@
-GOOF----LE-8-2.0ě      ] 4     h2#      ] g  guile	 	g  define-module*	 	 	g  gnucash	g  report	g  owner-report		 	
+GOOF----LE-8-2.0̛      ] 4     h6#      ] g  guile	 	g  define-module*	 	 	g  gnucash	g  report	g  owner-report		 	
 g  filenameS	f  owner-report.scm	g  set-current-module	
  	 	g  process-use-modules	 	 	g  srfi	g  srfi-1	 	 	g  
 gnc-module	 	 	g  main	 	 	g  gettext	 	 	g  gnc:module-load	 f  gnucash/report/report-system	!g  standard-reports	"! 	#" 	$g  business-reports	%$ 	&% 	'f  From	(g  optname-from-date	)f  To	*g  optname-to-date	+f  Due or Post Date	,g  optname-date-driver	-f   08ae9c2e884b4f9787144f47eacd7f44	.g  employee-report-guid	/f   d7d1e53505ee4b1b82efad9eacedaea0	0g  vendor-report-guid	1f   c146317be32e4948a561ec7fc89d15c1	2g  customer-report-guid	3f  Account	4g  acct-string	5g  gnc:pagename-general	6g  
@@ -24,12 +24,13 @@ string-appendg  list->stringg  string->listg  
 string-expandg  gncOwnerReturnGUIDg  gncOwnerGetEndOwnerg  qof-query-add-guid-matchg  SPLIT-TRANSg  INVOICE-FROM-TXNg  
 INVOICE-OWNERg  
 OWNER-PARENTGg  QOF-QUERY-ORg  	SPLIT-LOTg  OWNER-FROM-LOTg  INVOICE-FROM-LOTg  xaccQueryAddSingleAccountMatch g  
-QOF-QUERY-AND!g  xaccQueryAddDateMatchTS"g  qof-query-set-book#g  gnc-get-current-book$g  setup-query%g  gnc:html-table-set-style!&f  table'g  	attribute(f  border)f  cellspacing*f  cellpadding+g  "gnc:owner-get-name-and-address-dep,f  <br>-f  td.f  valign/f  top0g  make-owner-table1f  :&nbsp;2f  &nbsp;3g  make-date-row!4g  make-date-table5g  qof-book-get-slots6g  kvp-frame-get-slot-path-gslist7g  gnc:*kvp-option-path*8g  gnc:*business-label*9g  gnc:*company-name*:g  gnc:*company-addy*;f  align<f  right=g  strftime>g  	localtime?g  
+QOF-QUERY-AND!g  xaccQueryAddDateMatchTS"g  qof-query-set-book#g  gnc-get-current-book$g  setup-query%g  gnc:html-table-set-style!&f  table'g  	attribute(f  border)f  cellspacing*f  cellpadding+g  "gnc:owner-get-name-and-address-dep,f  <br>-f  td.f  valign/f  top0g  make-owner-table1f  :&nbsp;2f  &nbsp;3g  make-date-row!4g  make-date-table5g  qof-book-get-slots6g  kvp-frame-get-slot-path-gslist7g  gnc:*kvp-option-path*8g  gnc:*business-label*9g  gnc:*company-name*:g  gnc:*company-addy*;f  align<f  right=g  strftime>g  
+gnc-localtime?g  
 gnc:get-today@g  make-myname-tableAg  gnc:html-document-add-object!Bg  gnc:html-markup-brCg  make-break!Dg  gnc:make-html-documentEg  qof-query-create-for-splitsFg  gnc:report-optionsGg  gnc:timepair-start-day-timeHg  gnc:date-option-absolute-timeIg  gnc:timepair-end-day-timeJf   Kf  ReportLg  gncOwnerIsValidMf  : Ng  gncOwnerGetNameOg  
 gnc:report-idPg  gnc:html-document-set-title!Qg  gnc:html-document-set-headline!Rg  gnc:html-markupSf  !Tf  Report:Ug  gnc:owner-anchor-textVf  
 Date RangeWf   - Xg  qof-query-destroyYg  reg-rendererZg  gnc-account-nth-child[g  xaccAccountGetType\g  gnc-get-current-root-account]g  gnc-account-n-children^g  find-first-account_g  gncOwnerGetType`g  
 GNC-OWNER-JOBag  find-first-account-for-ownerbg  gnc:define-reportcg  versiondg  nameef  Customer Reportfg  report-guidgg  	menu-pathhg  gnc:menuname-business-reportsig  rendererjg  in-menu?kf  
-Vendor Reportlf  Employee Reportmg  gnc:make-report-optionsng  gnc:make-reportog  owner-report-create-internalpg  owner-report-createqg  gncOwnerNewrg  gnc:owner-from-splitsg  gnc:owner-report-createtg  gncOwnerFreeug   gnc:owner-report-create-internalvg  gnc:register-report-hookwg  call-with-deferred-observersxw yw zg  module-export!{z |z }g  current-module~} } ap C 5 hr  j  ]4	
+Vendor Reportlf  Employee Reportmg  gnc:make-report-optionsng  gnc:make-reportog  owner-report-create-internalpg  owner-report-createqg  gncOwnerNewrg  gnc:owner-from-splitsg  gnc:owner-report-createtg  gncOwnerFreeug   gnc:owner-report-create-internalvg  gnc:register-report-hookwg  call-with-deferred-observersxw yw zg  module-export!{z |z }g  current-module~} } ap C 5     hr  j  ]4	
 5 4 >  "  G   4 >  "  G  4 >  "  G  4 >  "  G  4 >  "  G  4i 
 >  "  G  4# >  "  G  4& >  "  G  '(R)*R+,R-.R/0R12R34R5i6R78R9:R;<R=>R?@RABRCDREFRGHIJK h       ] $  C $  CC          g  
 owner-type
@@ -378,7 +379,7 @@ string-expand CR !"#        
 	  g  date-format	  g  table		  g  slots		  g  name		'  g  addy		>   g  filenamef  owner-report.scm
 
 					
-								#		%		'		'		*		/		:		<		>		>		A		G		I		K		O		Q		S		U		X		Z		\		^		a		c		e		i		k		m		q		v			 	, 	: 	& 	 	 	, 	 	' 	# 	, 	& 	 	 	 	 	$ 	 	 	 	& 	 <	 	  g  nameg  make-myname-table C@RAB   h      ] 445 56             g  document
+								#		%		'		'		*		/		:		<		>		>		A		G		I		K		O		Q		S		U		X		Z		\		^		a		c		e		i		k		m		q		v			 	, 	: 	& 	 	 	, 	 	' 	# 	, 	& 	 	 	 	 	( 	# 	 	 	& 	 <	 	  g  nameg  make-myname-table C@RAB   h      ] 445 56             g  document
 		  g  filenamef  owner-report.scm
 
 			
