@@ -1,9 +1,9 @@
-GOOF----LE-8-2.0E      ]  4 h       ] g  gnc:module-load	f  gnucash/html	g  guile	 	g  process-use-modules	 	 	g  gnucash		g  printf	
+GOOF----LE-8-2.0E      ]  4 h      ] g  gnc:module-load	f  gnucash/html	g  guile	 	g  process-use-modules	 	 	g  gnucash		g  printf	
 	 	
  	g  make-record-type	
 f  <html-document>	g  style-sheet	g  style-stack	g  style	g  
 style-text	g  title	g  headline	g  objects	 	g  <html-document>	g  record-predicate	g  gnc:html-document?	g  record-constructor	g  gnc:make-html-document-internal	g  gnc:make-html-style-table	f   	g  gnc:make-html-document	g  record-modifier	g  gnc:html-document-set-title!	 g  record-accessor	!g  gnc:html-document-title	"g  gnc:html-document-set-headline!	#g  gnc:html-document-headline	$g  "gnc:html-document-set-style-sheet!	%g  gnc:html-document-style-sheet	&g  "gnc:html-document-set-style-stack!	'g  gnc:html-document-style-stack	(g  !gnc:html-document-set-style-text!	)g  gnc:html-document-style-text	*g  %gnc:html-document-set-style-internal!	+g  gnc:html-document-style	,g  gnc:html-document-set-objects!	-g  gnc:html-document-objects	.g  gnc:make-html-markup-style-info	/g  length	0g  
-procedure?	1g  gnc:make-html-data-style-info	2g  gnc:html-style-table-set!	3g  gnc:html-document-set-style!	4g  for-each	5g  string?	6g  with-output-to-string	7g  display	8g  gnc:html-document-tree-collapse	9g  gnc:html-style-sheet-render	:g  gnc-html-engine-supports-css	;g  gnc:html-style-table-compile	<g  gnc:html-document-push-style	=g  string-null?	>g  gnc:report-render-starting	?f  n<!DOCTYPE!DOCTYPE html PUBLIC -//W3C//DTD HTML 4.01 Transitional//EN" 
+procedure?	1g  gnc:make-html-data-style-info	2g  gnc:html-style-table-set!	3g  gnc:html-document-set-style!	4g  for-each	5g  string?	6g  with-output-to-string	7g  display	8g  gnc:html-document-tree-collapse	9g  gnc:html-style-sheet-render	:g  gnc-html-engine-supports-css	;g  gnc:html-style-table-compile	<g  gnc:html-document-push-style	=g  string-null?	>g  gnc:report-render-starting	?f  g<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" 
 "http://www.w3.org/TR/html4/loose.dtd">	@f  <head>
 	Af  F<meta http-equiv="content-type" content="text/html; charset=utf-8" />
 	Bf  </style>	Cf  <style type="text/css">
@@ -16,7 +16,7 @@ procedure?	1g  gnc:make-html-data-style-info	2g  gnc:html-style-table-set!
 	sf  </	tf  >
 	ug  reverse	vg  gnc:html-document-markup-end	wg  number?	xf  <number>	yf  <string>	zg  boolean?	{f  	<boolean>	|g  record?	}g  record-type-name	~g  record-type-descriptor	f  	<generic> g  !gnc:html-data-style-info-renderer g  gnc:html-data-style-info-data g  gnc:html-document-render-data f  
 <html-object> g  renderer g  data   g  
-<html-object> g  gnc:html-object? g  gnc:make-html-object-internal g  gnc:html-text? g  gnc:html-text-render g  gnc:html-table? g  gnc:html-table-render g  gnc:html-table-cell? g  gnc:html-table-cell-render g  gnc:html-barchart? g  gnc:html-barchart-render g  gnc:html-piechart? g  gnc:html-piechart-render g  gnc:html-scatter? g  gnc:html-scatter-render g  gnc:html-linechart? g  gnc:html-linechart-render f  &nbsp;&nbsp;&nbsp; g  gnc:html-object-renderer g  gnc:html-object-set-renderer! g  gnc:html-object-data g  gnc:html-object-set-data!C 5   h0  5  ] 4i
+<html-object> g  gnc:html-object? g  gnc:make-html-object-internal g  gnc:html-text? g  gnc:html-text-render g  gnc:html-table? g  gnc:html-table-render g  gnc:html-table-cell? g  gnc:html-table-cell-render g  gnc:html-barchart? g  gnc:html-barchart-render g  gnc:html-piechart? g  gnc:html-piechart-render g  gnc:html-scatter? g  gnc:html-scatter-render g  gnc:html-linechart? g  gnc:html-linechart-render f  &nbsp;&nbsp;&nbsp; g  gnc:html-object-renderer g  gnc:html-object-set-renderer! g  gnc:html-object-data g  gnc:html-object-set-data!C 5  h0  5  ] 4i
 >  "  G  4 >  "  G  4i
 5R4ii5R4ii5R        h      ] 45 6             g  filenamef  html-document.scm
 	)
