@@ -1,4 +1,5 @@
-GOOF----LE-8-2.0      ]  4     hu      ] g  guile	 	g  process-use-modules	 	 	g  srfi	g  srfi-13	 		 	
+GOOF----LE-8-2.0-      ]  4        h
+      ] g  guile	 	g  process-use-modules	 	 	g  srfi	g  srfi-13	 		 	
 g  gnucash	g  printf	
  	
  	g   gnc-get-account-separator-string	g  qif-map-entry:gnc-name	g  hash-ref	g  gnc-account-lookup-by-full-name	g  qif-map-entry:allowed-types	g  xaccAccountGetType	g  xaccAccountGetCommodity	g  memv	g  gnc-commodity-equiv	g  xaccMallocAccount	g  gnc-get-current-book	g  throw	g  bug	f  qif-import:find-or-make-acct	f  .No valid account types allowed for account ~A.	g  GNC-STOCK-TYPE	g  GNC-MUTUAL-TYPE	g  gnc:string-rcontains	 g  xaccAccountBeginEdit	!g  xaccAccountSetName	"g  xaccAccountGetName	#g  xaccAccountSetDescription	$g  xaccAccountGetDescription	%g  xaccAccountSetType	&g  xaccAccountSetCommodity	'g  xaccAccountSetNotes	(g  xaccAccountGetNotes	)g  xaccAccountSetColor	*g  xaccAccountGetColor	+g  xaccAccountSetCode	,g  xaccAccountGetCode	-g  	substring	.g  
@@ -7,11 +8,11 @@ string-append	1g  sprintf	2f   %a	3g  _	4f  /QIF import: Name conflict wi
 qif-file:xtns	Gg  gnc-progress-dialog-set-sub	Hf  "Preparing to convert your QIF data	Ig  	hash-fold	Jg  qif-map-entry:display?	Kg  for-each	Lg  qif-split:category-is-account?	Mg  qif-xtn:splits	Nf  Creating accounts	Og  gnc:substring-count	Pg  qif-import:get-account-name	Qg  qif-map-entry:qif-name	Rg  GNC-EQUITY-TYPE	Sg  gnc-progress-dialog-set-value	Tg  qif-import:check-pause	Ug  qif-import:canceled	Vg  cancel	Wf  #Matching transfers between accounts	Xg  qif-xtn:mark	Yg  qif-import:mark-matching-xtns	Zf  
 Converting	[f   	\g  
 qif-file:path	]g  xaccMallocTransaction	^g  xaccTransBeginEdit	_g  xaccTransSetCurrency	`g  qif-import:qif-xtn-to-gnc-xtn	ag  xaccTransCommitEdit	bg  gnc:backtrace-if-exception	cg  catch	dg  bad-date	eg  qif-import:qif-to-gnc	fg  xaccMallocSplit	gg  gnc-numeric-zero	hg  
-qif-xtn:payee	ig  qif-xtn:number	jg  qif-xtn:action	kg  qif-xtn:security-name	lg  qif-xtn:default-split	mg  qif-xtn:date	ng  qif-xtn:from-acct	og  qif-xtn:cleared	pg  list-ref	qg  qif-import:log	rf  qif-import:qif-xtn-to-gnc-xtn	sf  *Dates earlier than 1970 are not supported.	tf  Invalid transaction year (~A).	ug  apply	vg  xaccTransSetDate	wf  Missing transaction date.	xg  xaccTransSetDescription	yg  gnc-set-num-action	zg  qif-split:memo	{f   	|g  xaccTransSetNotes	}g  cleared	~g  xaccSplitSetReconcile	g  
-reconciled g  qif-xtn:share-price g  qif-xtn:num-shares g  qif-split:amount g  qif-xtn:commission g  sell g  sellx g  shrsout g  gnc-numeric-add g  
+qif-xtn:payee	ig  qif-xtn:number	jg  qif-xtn:action	kg  qif-xtn:security-name	lg  qif-xtn:default-split	mg  qif-xtn:date	ng  qif-xtn:from-acct	og  qif-xtn:cleared	pg  apply	qg  xaccTransSetDate	rg  qif-import:log	sf  qif-import:qif-xtn-to-gnc-xtn	tf  Missing transaction date.	ug  xaccTransSetDescription	vg  gnc-set-num-action	wg  qif-split:memo	xf   	yg  xaccTransSetNotes	zg  cleared	{g  xaccSplitSetReconcile	|g  
+reconciled	}g  qif-xtn:share-price	~g  qif-xtn:num-shares	g  qif-split:amount g  qif-xtn:commission g  sell g  sellx g  shrsout g  gnc-numeric-add g  
 GNC-DENOM-LCD g  gnc-numeric-sub g  gnc-numeric-mul g  GNC-DENOM-REDUCE g  gnc-numeric-zero-p g  gnc-numeric-div g  gnc:warn f  qif-import:qif-xtn-to-gnc-xtn:  f  splits in stock transaction! g  qif-split:accounts-affected g  string? g  string=? g  buy g  buyx g  reinvint g  reinvdiv g  reinvsg g  reinvsh g  reinvmd g  reinvlg g  xaccSplitSetAmount g  xaccSplitSetValue g  gnc-numeric-neg g  cgshort g  cgshortx g  cgmid g  cgmidx g  cglong g  cglongx g  intinc g  intincx g  div g  divx g  miscinc g  miscincx g  xin g  rtrncap g  rtrncapx g  xout g  miscexp g  miscexpx g  margint g  margintx g  shrsin g  stksplit g  gnc-numeric-create g  xaccAccountGetBalance g  qif-split:matching-cleared g  xaccSplitSetParent g  xaccSplitSetAccount g  qif-split:mark g  qif-split:category g  xaccSplitSetMemo g  string-prefix? f  **VOID** g  
 xaccTransVoid f  QIF g  qif-import:mark-some-splits g  qif-split:miscx-category g  reverse g  qif-import:xtn-has-matches? g  qif-import:merge-and-mark-xtns g  
-one-to-one g  many-to-one g  one-to-many g  gnc-numeric-equal g  default-stock-acct g  default-cgshort-acct g  default-cglong-acct g  default-cgmid-acct g  default-interest-acct g  default-margin-interest-acct g  default-capital-return-acct g  default-dividend-acct g  default-equity-holding g  default-commission-acct g  qif-xtn:mark-split g  qif-import:merge-xtn-info g  qif-split:set-matching-cleared! g  qif-xtn:set-payee! g  qif-xtn:address g  qif-xtn:set-address! g  qif-xtn:set-number! g  qif-split:set-mark! g  qif-xtn:set-mark! g  !gnc:account-tree-get-transactions g  xaccTransDestroy g  xaccAccountDestroy g  qif-import:qif-to-gnc-undoC 5      hhz     ] 4	 >  "  G  4
+one-to-one g  many-to-one g  one-to-many g  gnc-numeric-equal g  default-stock-acct g  default-cgshort-acct g  default-cglong-acct g  default-cgmid-acct g  default-interest-acct g  default-margin-interest-acct g  default-capital-return-acct g  default-dividend-acct g  default-equity-holding g  default-commission-acct g  qif-xtn:mark-split g  qif-import:merge-xtn-info g  qif-split:set-matching-cleared! g  qif-xtn:set-payee! g  qif-xtn:address g  qif-xtn:set-address! g  qif-xtn:set-number! g  qif-split:set-mark! g  qif-xtn:set-mark! g  !gnc:account-tree-get-transactions g  xaccTransDestroy g  xaccAccountDestroy g  qif-import:qif-to-gnc-undoC 5 hpy     ] 4	 >  "  G  4
  >  "  G     hh   J  ] $   "  $  M 64  5$  $  
   " C$   C  "   B      g  
 allowed-types
@@ -194,7 +195,7 @@ work-to-do		Ln g  	work-done			On g  xtn
    C h8   o  , 3 	O  Q O 6     g      g  qif-files-list
 		3 g  qif-acct-map		3 g  qif-cat-map			3 g  qif-memo-map			3 g  	stock-map			3 g  default-currency-name			3 g  transaction-status-pref			3 g  progress-dialog			3 g  private-convert			3  	g  filenamef  qif-to-gnc.scm
  
-	3	 		3	  g  nameg  qif-import:qif-to-gnc CeRMfghijklmnopqr3sdtuvwxyz{|}~EKfzg{LE}~   hX    ]I4 5$  C445 54 5L	$  4 5"  4 5HHHHJ$  "  45 KM J	4	
+	3	 		3	  g  nameg  qif-import:qif-to-gnc CeRMfghijklmnopqrs3tduvwxyz{|}~EKfwgxLEz{| hX    ]I4 5$  C445 54 5L	$  4 5"  4 5HHHHJ$  "  45 KM J	4	
 	5	N 4
 J45>  "  G  4J45>  "  G  $  4
 >  "  G  "   45$  "  4 5$  4L5K"  45$  4L5$  k4L5$  4L5$  "  	4LL5"  $  "  +4M5$  4M5$  "  	4LM5"  "  +45$  45$  "  	4L5"  KJ$  "  4L5K"  4L5K4J5K4LJ5K4 5&  4c>  "  G  "   &  4y>  "  G  "   4J>  "  G  L6           g  	qif-split
@@ -202,191 +203,190 @@ work-to-do		Ln g  	work-done			On g  xtn
 gnc-far-split	<S g  
 far-acct-info		<S g  
 far-acct-name		<S g  far-acct		<S g  	split-amt		<S g  memo		<S g  cat		<S g  a		_	u g  b			_	u g  n		~  g  n	   g  t	F g  cleared	7  g  filenamef  qif-to-gnc.scm
-				
-	
-		&		'		&	#	"	)&		*'		6(		<		P*		U*	7	[*	'	_.	*	d		w.		x/		~/	4 	 /	 0	 0	5 	 0	 2	 2	 7	 7	- 7	 7	 8	 5	 9	) 9	<	<	(
-<	5	G	"G	G	H	(&H	#'I	--I	A/I	-3H	#9J	(FH	UK	(_K	#`L	-fL	@hL	-lK	#rM	(N	$N	O	)O	8O	)N	P	$F	Q	R	-R	=	)=	T	'T	U	"U	X	"X	Y	Y	Z	[	[	\	8_	S`	 U	S   C c      h  Z  , 	3 +4 5445 545 4 54 54 54 54	 54
+				
+	
+		&		'		&		"	)		*		6 		<		P"		U"	7	["	'	_&	*	d		w&		x'		~'	4 	 '	 (	 (	5 	 (	 *	 *	 /	 /	- /	 /	 0	 -	 1	) 1	4	4	(
+4	-	?	"?	?	@	(&@	#'A	--A	A/A	-3@	#9B	(F@	UC	(_C	#`D	-fD	@hD	-lC	#rE	(F	$F	G	)G	8G	)F	H	$>	I	J	-J	5	)5	L	'L	M	"M	P	"P	Q	Q	R	S	S	T	8W	SX	 U	S   C `      h    , 	3 +4 5445 545 4 54 54 54 54	 54
  54 54 5HHH
 HH
-	$  r4
-	5$  B445>  "  G  44
-	5 >  "  G  "  44
- 5>  "  G  "  3445>  "  G  4>  "  G  $  4>  "  G  "   $  4
+	$  4
+4
+ 5>  "  G  "  3445>  "  G  4>  "  G  $  4>  "  G  "   $  4
 >  "  G  "   $  
-45K"  44 55KJ$  D$  	"  $  4J>  "  G  "  4J>  "  G  "   &  4
-c>  "  G  "  4&  4
-y>  "  G  "  4
->  "  G  $ 4  5H4! 5HH4"4 55HHHHH H!H"H#4# 5$H%445 5&J$  "  45 K$  W$$  I$$  "  %$  "  &$  4'$
-(5K"  4)$
-(5K"  K"  -J$   JJ('4*'(
-+5'(K"  45 KJ$  9$  /4,J5$  "  JJ('4-'(
-+5'(K"   "  45 K4.	5$  4/01>  "  G  "   424 5 5KJKJKJKJ$  J$  43J5''$  '"  	43J5'K44J5K
-43J
-5K45J5''$  "  	46J5'$  9434 55''$  '"  4344 555'K "   J $  "  %43J5''$  '"  	43J5'K 44J 5K!43J!5K""   "   7$  "  Y8$  "  K9$  "  =:$  "  /;$  "  !<$  "  =$  "  >$  oJ$  "  45 K4?
-J>  "  G  4@
-J>  "  G  4@&4A5>  "  G  4?&4A5>  "  G  " $$  "  %$  }J$  "  45 K4?
-J'4A'5'>  "  G  4@
-J'4A'5'>  "  G  4@&>  "  G  4?&>  "  G  " VB$  "  C$  "  D$  "  E$  "  F$  "  G$  "  uH$  "  gI$  "  YJ$  "  KK$  "  =L$  "  /M$  "  !N$  "  O$  "  P$  ^4@
->  "  G  4?
->  "  G  4@&4A5>  "  G  4?&4A5>  "  G  " +Q$  "  /R$  "  !S$  "  T$  "  U$  ^4@
-4A5>  "  G  4?
-4A5>  "  G  4@&>  "  G  4?&>  "  G  " V$  ^4?
-J>  "  G  4@
-J>  "  G  4@&4A5>  "  G  4?&4A5>  "  G  " %&$  l4?
-J'4A'5'>  "  G  4@
-J'4A'5'>  "  G  4@&>  "  G  4?&>  "  G  "  W$  J4X	
-5('4-'(
-+5'('4YJ5(4*('
-+5)4?
-)>  "  G  4?&4A(5>  "  G  4@
-J*4A*5*>  "  G  4@&J>  "  G  )('"   4Z4 55''&  4&c>  "  G  "   '&  4&y>  "  G  "   'J$  X43J5''$  '"  	43J5'''$  44'5"  (($  43(5K#"   ('"   $$  BJ#$  8445 5K%4@J%$>  "  G  4?J%$>  "  G  "   "   J$  J$  4[
->  "  G  4\
-J>  "  G  4[&>  "  G  4\&J">  "  G  J%$  ,4[J%>  "  G  4\J%J#>  "  G  "   "   "   &%$#"! "  435K44J5K
-43J
-5K4]^	O 
-	>  "  G  4@
-J>  "  G  4?
-J>  "  G  4[
->  "  G  4\
-J>  "  G  455$  )4_`5$  4ab>  "  G  "   "   C   R      g  qif-xtn
+45K"  44 55KJ$  D$  	"  $  4J>  "  G  "  4J>  "  G  "   &  4
+c>  "  G  "  4&  4
+y>  "  G  "  4
+>  "  G  $ 4 5H4 5HH44 55HHHHH H!H"H#4  5$H%445 5&J$  "  45 K$  W$$  I!$  "  "$  "  #$  4$$
+%5K"  4&$
+%5K"  K"  -J$   JJ('4''(
+(5'(K"  45 KJ$  9$  /4)J5$  "  JJ('4*'(
+(5'(K"   "  45 K4+	5$  4,-.>  "  G  "   4/4 5 5KJKJKJKJ$  J$  40J5''$  '"  	40J5'K41J5K
+40J
+5K42J5''$  "  	43J5'$  9404 55''$  '"  4044 555'K "   J $  "  %40J5''$  '"  	40J5'K 41J 5K!40J!5K""   "   4$  "  Y5$  "  K6$  "  =7$  "  /8$  "  !9$  "  :$  "  ;$  oJ$  "  45 K4<
+J>  "  G  4=
+J>  "  G  4=&4>5>  "  G  4<&4>5>  "  G  " !$  "  "$  }J$  "  45 K4<
+J'4>'5'>  "  G  4=
+J'4>'5'>  "  G  4=&>  "  G  4<&>  "  G  " V?$  "  @$  "  A$  "  B$  "  C$  "  D$  "  uE$  "  gF$  "  YG$  "  KH$  "  =I$  "  /J$  "  !K$  "  L$  "  M$  ^4=
+>  "  G  4<
+>  "  G  4=&4>5>  "  G  4<&4>5>  "  G  " +N$  "  /O$  "  !P$  "  Q$  "  R$  ^4=
+4>5>  "  G  4<
+4>5>  "  G  4=&>  "  G  4<&>  "  G  " S$  ^4<
+J>  "  G  4=
+J>  "  G  4=&4>5>  "  G  4<&4>5>  "  G  " %#$  l4<
+J'4>'5'>  "  G  4=
+J'4>'5'>  "  G  4=&>  "  G  4<&>  "  G  "  T$  J4U	
+5('4*'(
+(5'('4VJ5(4'('
+(5)4<
+)>  "  G  4<&4>(5>  "  G  4=
+J*4>*5*>  "  G  4=&J>  "  G  )('"   4W4 55''&  4&c>  "  G  "   '&  4&y>  "  G  "   'J$  X40J5''$  '"  	40J5'''$  41'5"  (($  40(5K#"   ('"   $$  BJ#$  8445 5K%4=J%$>  "  G  4<J%$>  "  G  "   "   J$  J$  4X
+>  "  G  4Y
+J>  "  G  4X&>  "  G  4Y&J">  "  G  J%$  ,4XJ%>  "  G  4YJ%J#>  "  G  "   "   "   &%$#"! "  405K41J5K
+40J
+5K4Z[	O 
+	>  "  G  4=
+J>  "  G  4<
+J>  "  G  4X
+>  "  G  4Y
+J>  "  G  425$  )4\]5$  4^_>  "  G  "   "   C            g  qif-xtn
 	 g  qif-file	 g  gnc-xtn		 g  
 gnc-acct-hash		 g  qif-acct-map		 g  qif-cat-map		 g  qif-memo-map		 g  transaction-status-pref		 g  progress-dialog		 g  splits			X g  gnc-near-split	
 	X g  near-split-total		X g  near-acct-info		X g  near-acct-name	
 	X g  	near-acct		X g  	qif-payee		X g  
 qif-number		X g  
 qif-action		X g  qif-security		X g  qif-default-split		X g  qif-memo		X g  qif-date		X g  
-qif-from-acct		X g  qif-cleared		X g  share-price	- g  
-num-shares	6
- g  	split-amt	9
- g  xtn-amt	H g  	qif-accts	K g  
-qif-near-acct	N g  qif-far-acct	Q
- g  qif-commission-acct	T
+qif-from-acct		X g  qif-cleared		X g  share-price	
  g  
-far-acct-info	 W
+num-shares	
+ g  	split-amt	
+ g  xtn-amt	
+ g  	qif-accts	
  g  
-far-acct-name	!Z
- g  far-acct	"]
- g  commission-acct	#`
- g  commission-amt	$i
- g  commission-split	%l
+qif-near-acct	
+ g  qif-far-acct	
+ g  qif-commission-acct	
  g  
-gnc-far-split	&x
- g  a	' g  b	( g  a	'4J g  b	(4J g  t	' g  t	'	 g  t	'@ g  t	'Ys g  n	' g  n	' g  n	'@L g  n	'`l g  a	' g  b	( g  
-splitratio	'	Q g  	in-shares	(	N g  
-out-shares	)	K g  n	*		' g  cleared	'	b	 g  t	'		 g  commission-acct-info	'	
- g  commission-acct-name	(		  =g  filenamef  qif-to-gnc.scm
+far-acct-info	 
+ g  
+far-acct-name	!
+ g  far-acct	"
+
+ g  commission-acct	#
+
+ g  commission-amt	$
+ g  commission-split	%
+ g  
+gnc-far-split	&%
+ g  a	' g  b	( g  a	' g  b	( g  t	'e g  t	' g  t	' g  t	'  g  n	'GS g  n	'gs g  n	' g  n	'
+ g  a	'e{ g  b	(e{ g  
+splitratio	'{ g  	in-shares	( g  
+out-shares	) g  n	* g  cleared	'		T g  t	'	c	} g  commission-acct-info	'	}	 g  commission-acct-name	(		  =g  filenamef  qif-to-gnc.scm
 
-						)					 		'		.		5		<		D		K		R		X		|		}	
- 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	( 	 	 	 	 	 		
-					'	(	E	F	f	g	o	t	w	+~	&					$			
- 						
-	
-		
-
-	&	'm	-m	0n	6m	<p	?p	/Fp	*Hp	Hm	cy	im	o{	r{	/x{	xm	}	
-}	0}		
-									"	
-		"		
-!	"	$,	4	$9	L	U	 [	\	d	h	
-i	m	o	t			2	-		
-		
-		
-	$	
-	
-						%		 						/	
-			5		*	/	(2	/9	*;	(=	B	L	Q	Y	h	u	v	$~				
-	
-	5
-	#	
-"	
-6	
-;	F	
-O	
-T	_	
-t	
-	
-	5	#	
-	0		
-	
-	/		
+						)					 		'		.		5		<		D		K		R		X		|		}	 	( 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 				!	$	++	&-	/	5	;	?	$@	E	I	
+J	b	} 	 							e	e	f	e	h	h	/h	*h	e	q	e	s	s	/%s	%e	-u	
+2u	08u	>x	
+Dz	M{	j	w}	|					"			"		
+		$		$			 					
+			!	.	1	28	-<	>	
+A	C	
+F	I	
+L	$P	
+V	
+\	]	e	t			%		 						/				5				(	/	*	(						"	#	$+	,	6	G	
+	
+	5	#	
+	
+	
+		
+	
+		
+!	
+5	
+:	5@	#A	
+G	0J	X	
+a	
+g	/j	x	
 	
 	
-	
+	
+z	
 	
 	
+		
 	
-		
-	
-		
-3	
-l	
-q	|	
+		
+	
+	
+	)	
+2	
+7	B	
+K	
+_	
+	
+	
+	
+	
+		
 	
 		
 	
 	
-	
-	
-	
-	
- 		
-	
-	$	
-9	
-:	
-@	0C	Q	
-Z	
-`	/c	q	
-z	
-	
-	
-	/	 		
-		
+	0		
+	
+
+	/		
+'	
+;	
+[	
+^	/e	 j	{	
+~		
 		
-										1			,		5		V		Y 		` 		b		b	
-	f		l		m									
-																
-					
-	
+						1								
+					
+							3		9		:		Z	
+	[ 		c 		r		}																
+					'		(		'			
+			
+ 	
 
-	
-	'
-	(
-	'
-	
-	
-2	
-S	
+	
+	
+	
+/	
+C	
+\	
+]	
+q	
+
+	
+
+	
 
-Y	
-Z	
-n	
-	
-	
- 	
-"	
-#			
- 	(	
-)	3	
-4	
-_d	
-se	
-f	
-g	
-'	
-'	(	
-(	(	
-'	)	)	)	8			  g  nameg  qif-import:qif-xtn-to-gnc-xtn C`RLM       h`   ]  ]
+	
+	
+
+	
+	
+
+	
+\	
+ ]	
+4^	
+H_	
+\	
+f	g 	
+k 	o 	
+s	t!	z!	!	(			  g  nameg  qif-import:qif-xtn-to-gnc-xtn C`RLM       h`   ]  ]
 "  MJ(  "  34J5$  "  4J5$  4J 5K"  JKJ(  CJH"4 5H"U      g  xtn
 		` g  candidate-xtns		` g  splits-left			S  g  filenamef  qif-to-gnc.scm
-5
-	6		<		=		=	&	=		=		">		'>	1	)>		-=		.@		:?		AB		CB		ID		SE		S6		T6		`6	 		`	  g  nameg  qif-import:mark-matching-xtns CYRmkjngKL h`      ]"  	 M N C4 5$  @4M4 55$  * MNM4 54
+-
+	.		4		5		5	&	5		5		"6		'6	1	)6		-5		.8		:7		A:		C:		I<		S=		S.		T.		`.	 		`	  g  nameg  qif-import:mark-matching-xtns CYRmkjngKL h`      ]"  	 M N C4 5$  @4M4 55$  * MNM4 54
 5NC""         g  s
 		^ g  a	<	R g  b		<	R  g  filenamef  qif-to-gnc.scm
-m		u		
-t		n	
-	n		n	
-	o		 o	.	(o		,n		1r		3q		6s	9	<s	&	AP		Ts	 		^   CX !      h    ]s HH454545HH45	45
+e		m		
+l		f	
+	f		f	
+	g		 g	.	(g		,f		1j		3i		6k	9	<k	&	AH		Tk	 		^   CX !      h    ]s HH454545HH45	45
 HHH
 H	$ 845KK K
 $ 
@@ -414,21 +414,21 @@ far-acct-name		 g  date		 g  n			) g  amount		) g  
 security-name			5 g  action	
 	> g  different-acct-splits		A g  same-acct-splits		D g  how	
 	G g  done		J g  	qif-accts		[ g  n	   g  n	+ g  n	my g  xtns	Y g  key	j  g  filenamef  qif-to-gnc.scm
-N
-	T		O		W		O		X		X		 O		)O		/Z		5O		8[		>O		A]	 	AO		D^		DO		Rb		S~		[}		`		b	
-	e		h	
-	m	!	o	
-	u	
-	~	 	 O	 	 	& 	 	%			"O	-	.	&6	7	%?	L	M	&U	V	%^	k	m	pO	{	d	d	
-e	e	
-f	f	
-l	
-x	!x	
-y	&y	
+F
+	L		G		O		G		P		P		 G		)G		/R		5G		8S		>G		AU	 	AG		DV		DG		RZ		Sv		[u		`w		bw	
+	ex		hx	
+	my	!	oy	
+	uz	
+	~~	 	 G	 	 	& 	 	%	~		"G	-	.	&6	7	%?	L~	M	&U	V	%^	k~	m	pG	{	\	\	
+]	]	
+^	^	
+d	
+p	!p	
+q	&q	
 			"		
 			,					/					2%	0	>	
 F	G	H	L	O	U	
-Y	g	j	j				 b		  g  nameg  qif-import:mark-some-splits CRgmELkjM       hP    ]]45 4 5$  a$  U45	&  C45	&  1$  !$  "  "  "  "  "  "  HHH$ " 	
+Y	g	j	j				 b		  g  nameg  qif-import:mark-some-splits CRgmELkjM       hP    ]]45 4 5$  a$  U45	&  C45	&  1$  !$  "  "  "  "  "  "  HHH$ " 	
 4
 5$ Q45$ B44
 55$ ,4
@@ -474,49 +474,48 @@ $  4+5K"  $  "  !$  "  $  4,5K"  $  "  
 K4$ 5KJJJ C           g  split
 	 g  xtn	 g  near-acct-name		 g  
 far-acct-name		 g  commission-acct-name		 g  security		 g  action		 g  	from-acct		  g  filenamef  qif-to-gnc.scm
-
-			
-		
-				,		5	
- 	" 	
- 	
-"	
-	
-%	%	,%	'%	$	
-	
-(	(	2(	-(	'	
-,-	
->/	
-K-	
-2	2	,2	'2	1	
--	
-4	!4	
--	
-7	6	
-#-	
-@:	J9	
-W-	
-t=	~<	
--	
-@	?	
--	
-C	B	
--	
-F	E	
-	-	
-&I	0H	
-=-	
-LL	TK	
-YO	cO	
-dQ	lP	x	
-y		
-S	 C		  g  nameg  qif-split:accounts-affected CRjkKo   h   d   ] 4L 56 \       g  s
+
+			
+				 		,		5	
+ 	" 	
+ 	
+	
+	
+		,	'		
+	
+ 	 	2 	- 		
+,%	
+>'	
+K%	
+*	*	,*	'*	)	
+%	
+,	!,	
+%	
+/	.	
+#%	
+@2	J1	
+W%	
+t5	~4	
+%	
+8	7	
+%	
+;	:	
+%	
+>	=	
+	%	
+&A	0@	
+=%	
+LD	TC	
+YG	cG	
+dI	lH	x	
+y		
+K	 C		  g  nameg  qif-split:accounts-affected CRjkKo   h   d   ] 4L 56 \       g  s
 		  g  filenamef  qif-to-gnc.scm
-m		n	-	n	
+e		f	-	f	
  		   Co  h   d   ] 4L 56 \       g  s
 		  g  filenamef  qif-to-gnc.scm
-w		y	
-	x	
+o		q	
+	p	
  		   CEMo   hP  k  ]<4 5454 545
 		$  54 >  "  G  4 >  "  G   O 
 6	$  64
@@ -544,14 +543,14 @@ far-acct-name		 g  commission-acct-name		 g  security		 g
 o-security		'J g  split		'J g  
 match-type			'J g  match-splits	
 	'J  g  filenamef  qif-to-gnc.scm
-\
-	^		
-_		`		a		!b		$c		'd		'^		>e		?j		Sk		sl		|e		}t	 t	% t	 u	 v	 	 	 	 	 	 	 		 ~	 	 	 	 	#										"~	#	*	-/	8	P	X	^		t~	u					
+T
+	V		
+W		X		Y		!Z		$[		'\		'V		>]		?b		Sc		sd		|]		}l	 l	% l	 m	 n	 {	 {	 {	 |	 |	 |	 {		 v	 }	 ~	 	 	#										"v	#	*	-/	8	P	X	^		tv	u					
 				
 	(	
 	
 		
-~						'				)	1		7		F					
+v						'				)	1		7		F					
  	 				*		6	>	 Q	J	  g  nameg  qif-import:merge-and-mark-xtns CRhi  h   L  ]4 5$  ,45$  "  44 5>  "  G  "   4 5$  ,45$  "  44 5>  "  G  "   4 5$  45$  C4 56C D      g  from-xtn
 	  g  to-xtn	   g  filenamef  qif-to-gnc.scm
 
@@ -572,14 +571,14 @@ all-marked			_ g  splits			C  g  filenamef  qif-to-gnc.scm
 		
 	&
 )2 
-O}
-QX5
-[N
-cF
-l 
-u\
-w
-x
-ze
- 	zg
+N
+P`-
+ZF
+bN
+k
+tT
+v
+w
+ym
+ 	yo
    C6 
\ No newline at end of file
